# Flutter Installer

Flutter Installer is a Flutter package designed to assist with file operations within your application's documents directory. It provides an easy-to-use API for installing, deleting, checking, reading, copying, and renaming files.

## Features:

- Install file from a list of bytes
- Install file from application assets
- Delete specific file
- Delete all files in the directory
- Check if a file exists
- Read file content
- Copy a file
- Rename a file

## Installation

To use this package, add `flutter_installer` as a dependency in your `pubspec.yaml` file.

## Usage

First, import the package:

```dart
import 'package:flutter_installer/flutter_installer.dart';
```

Then, create an instance of the FlutterInstaller class:

```dart
FlutterInstaller installer = FlutterInstaller();
```

You can specify a directory name while creating the FlutterInstaller object. If not specified, it defaults to 'flutter_installer':

```dart
FlutterInstaller installer = FlutterInstaller(mainDirectory: 'my_directory');
```

## Methods

Here are some examples of using the `FlutterInstaller` methods:

### install

Install a file from a list of bytes:

```dart
String filePath = await installer.install(
  fileBytes: myFileBytes,
  name: 'myfile.txt',
  replace: true
);
```

### installFromAssets

Install a file from application assets:

```dart
String filePath = await installer.installFromAssets(
  assetPath: 'assets/myfile.txt',
  name: 'myfile.txt',
  replace: true
);
```

### deleteFile

Delete a specific file:

```dart
bool isDeleted = await installer.deleteFile('myfile.txt');
```

### deleteAllFiles

Delete all files in the directory:

```dart
await installer.deleteAllFiles();
```

### isFileExists

Check if a file exists:

```dart
bool exists = await installer.isFileExists('myfile.txt');
```

### readFile

Read a file:

```dart
List<int> fileContent = await installer.readFile('myfile.txt');
```

### copyFile

Copy a file:

```dart
String newFilePath = await installer.copyFile(
  existingFileName: 'myfile.txt',
  newFileName: 'copied_myfile.txt'
);
```

### renameFile

Rename a file:

```dart
String newFilePath = await installer.renameFile(
  existingFileName: 'myfile.txt',
  newFileName: 'renamed_myfile.txt'
);
```

## Exception Handling

All methods throw a `FlutterInstallerException` in case of any errors during execution. It's recommended to use try-catch blocks to handle these exceptions.

## Contributions

If you encounter any problem or the library is missing a feature feel free to open an issue. Feel free to fork, improve the package and make pull request.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
